Customizing style.css file in Askbot — Askbot 0.12.7 documentation

# Askbot Project Documentation

Home | Ask Questions | Consulting Services | Documentation | Contribute | Contact

# Customizing style.css file in Askbot

File style.css is produced by the lesscss compiler - `lessc`.

Please find documentation about the lesscss format elsewhere.

Note

Besides the “official” lesscss compiler, there are other tools that convert .less files into .css: for example a less compiler from codekit (mac) and a portable SimpLESS compiler.

## Compiling lesscss files

The following command will compile the lesscss source file, an option -x will produce compressed css file:

> lessc file.lesscss -x > file.css

## Installing lesscss

Make sure you have recent version of node.js - latest version preferred. More recent versions of node come with the tool called npm, for earlier versions `npm` will need to be installed manually.

To install lesscss, type:

> sudo npm install less